@@ -1,3 +1,4 @@
+import base64
 import zlib
 
 from pynamodb.attributes import Attribute
@@ -11,14 +12,14 @@ class CompressedAttribute(Attribute[bytes]):
 
     attr_type = BINARY
 
-    def serialize(self, value):
+    def serialize(self, value: str) -> str:
         """
         Returns the compressed binary of the value
         """
-        return zlib.compress(value)
+        return base64.b64encode(zlib.compress(value.encode("utf-8"))).decode("utf-8")
 
-    def deserialize(self, value):
+    def deserialize(self, value: bytes) -> str:
         """
         Returns a decoded byte string from a base64 encoded value
         """
-        return zlib.decompress(value)
+        return zlib.decompress(base64.b64decode(value)).decode("utf-8")
